@@ -1,23 +1,19 @@
 /******************************************************************************
-*   TinTin++                                                                  *
-*   Copyright (C) 2004 (See CREDITS file)                                     *
+*    TinTin++  Copyright (C) 2004 (See CREDITS file)                          *
 *                                                                             *
-*   This program is protected under the GNU GPL (See COPYING)                 *
+*    This program is free software: you can redistribute it and/or modify     *
+*    it under the terms of the GNU General Public License as published by     *
+*    the Free Software Foundation, either version 2 of the License, or        *
+*    (at your option) any later version.                                      *
 *                                                                             *
-*   This program is free software; you can redistribute it and/or modify      *
-*   it under the terms of the GNU General Public License as published by      *
-*   the Free Software Foundation; either version 2 of the License, or         *
-*   (at your option) any later version.                                       *
+*    This program is distributed in the hope that it will be useful,          *
+*    but WITHOUT ANY WARRANTY; without even the implied warranty of           *
+*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
+*    GNU General Public License for more details.                             *
 *                                                                             *
-*   This program is distributed in the hope that it will be useful,           *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
-*   GNU General Public License for more details.                              *
-*                                                                             *
-*   You should have received a copy of the GNU General Public License         *
-*   along with this program; if not, write to the Free Software               *
-*   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
-*******************************************************************************/
+*    You should have received a copy of the GNU General Public License        *
+*    along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
+******************************************************************************/
 
 /******************************************************************************
 *                (T)he K(I)cki(N) (T)ickin D(I)kumud Clie(N)t                 *
@@ -587,7 +583,7 @@ DO_COMMAND(do_kill)
 		{
 			kill_list(ses->list[index]);
 		}
-		tintin_printf(ses, "#KILL - ALL LISTS CLEARED.");
+		show_message(ses, LIST_COMMAND, "#KILL - ALL LISTS CLEARED.");
 
 		return ses;
 	}
@@ -603,7 +599,7 @@ DO_COMMAND(do_kill)
 		{
 			kill_list(ses->list[index]);
 
-			tintin_printf(ses, "#OK: #%s LIST CLEARED.", list_table[index].name);
+			show_message(ses, LIST_COMMAND, "#OK: #%s LIST CLEARED.", list_table[index].name);
 		}
 		else
 		{
@@ -614,7 +610,7 @@ DO_COMMAND(do_kill)
 
 	if (index == LIST_MAX)
 	{
-		tintin_printf(ses, "#ERROR: #KILL {%s} {%s} - NO MATCH FOUND.", arg1, arg2);
+		show_error(ses, LIST_COMMAND, "#ERROR: #KILL {%s} {%s} - NO MATCH FOUND.", arg1, arg2);
 	}
 	return ses;
 }
@@ -669,16 +665,16 @@ DO_COMMAND(do_message)
 			}
 			else
 			{
-				tintin_printf(ses, "#SYNTAX: #MESSAGE [NAME] [ON|OFF]");
-				break;
+				return show_error(ses, LIST_COMMAND, "#SYNTAX: #MESSAGE {%s} [ON|OFF]",  left);
 			}
-			tintin_printf(ses, "#OK: #%s MESSAGES HAVE BEEN SET TO: %s.", list_table[index].name, HAS_BIT(ses->list[index]->flags, LIST_FLAG_MESSAGE) ? "ON" : "OFF");
+			show_message(ses, LIST_COMMAND, "#OK: #%s MESSAGES HAVE BEEN SET TO: %s.", list_table[index].name, HAS_BIT(ses->list[index]->flags, LIST_FLAG_MESSAGE) ? "ON" : "OFF");
+
 			found = TRUE;
 		}
 
 		if (found == FALSE)
 		{
-			tintin_printf(ses, "#ERROR: #MESSAGE {%s} - NO MATCH FOUND.", left);
+			show_error(ses, LIST_COMMAND, "#ERROR: #MESSAGE {%s} - NO MATCH FOUND.", left);
 		}
 	}
 	return ses;
@@ -735,16 +731,16 @@ DO_COMMAND(do_ignore)
 			}
 			else
 			{
-				tintin_printf(ses, "#SYNTAX: #IGNORE [NAME] [ON|OFF]");
-				break;
+				return show_error(ses, LIST_COMMAND, "#SYNTAX: #IGNORE {%s} [ON|OFF]", left);
 			}
-			tintin_printf(ses, "#OK: #%s IGNORE STATUS HAS BEEN SET TO: %s.", list_table[index].name, HAS_BIT(ses->list[index]->flags, LIST_FLAG_IGNORE) ? "ON" : "OFF");
+			show_message(ses, LIST_COMMAND, "#OK: #%s IGNORE STATUS HAS BEEN SET TO: %s.", list_table[index].name, HAS_BIT(ses->list[index]->flags, LIST_FLAG_IGNORE) ? "ON" : "OFF");
+
 			found = TRUE;
 		}
 
 		if (found == FALSE)
 		{
-			tintin_printf(ses, "#ERROR: #IGNORE {%s} - NO MATCH FOUND.", left);
+			show_error(ses, LIST_COMMAND, "#ERROR: #IGNORE {%s} - NO MATCH FOUND.", left);
 		}
 	}
 	return ses;
@@ -805,16 +801,16 @@ DO_COMMAND(do_debug)
 			}
 			else
 			{
-				tintin_printf(ses, "#SYNTAX: #DEBUG [NAME] [ON|OFF|LOG]");
-				break;
+				return show_error(ses, LIST_COMMAND, "#SYNTAX: #DEBUG {%s} [ON|OFF|LOG]", left);
 			}
-			tintin_printf(ses, "#OK: #%s DEBUG STATUS HAS BEEN SET TO: %s.", list_table[index].name, is_abbrev(right, "LOG") ? "LOG" : HAS_BIT(ses->list[index]->flags, LIST_FLAG_DEBUG) ? "ON" : "OFF");
+			show_message(ses, LIST_COMMAND, "#OK: #%s DEBUG STATUS HAS BEEN SET TO: %s.", list_table[index].name, is_abbrev(right, "LOG") ? "LOG" : HAS_BIT(ses->list[index]->flags, LIST_FLAG_DEBUG) ? "ON" : "OFF");
+
 			found = TRUE;
 		}
 
 		if (found == FALSE)
 		{
-			tintin_printf2(ses, "#DEBUG {%s} - NO MATCH FOUND.", left);
+			show_error(ses, LIST_COMMAND, "#DEBUG {%s} - NO MATCH FOUND.", left);
 		}
 	}
 	return ses;
