@@ -55,6 +55,7 @@ struct help_type help_table[] =
 		"\n"
 		"       ^ force match of start of line.\n"
 		"       $ force match of end of line.\n"
+		"       \\ escape one character.\n"
 		"  %1-%99 lazy match of any text, available at %1-%99.\n"
 		"      %0 should be avoided in triggers, and if left alone lists all matches.\n"
 		"     { } embed a raw regular expression, available at %1-%99 + 1.\n"
@@ -214,11 +215,12 @@ struct help_type help_table[] =
 	},
 	{
 		"CLASS",
-		"<178>Command<078>: #class <178>{<078>name<178>}<078> <178>{<078>open<178>|<078>close<178>|<078>read filename<178>|<078>write filename<178>|<078>kill<178>}<078>\n"
+		"<178>Command<078>: #class <178>{<078>name<178>}<078> <178>{<078>open<178>|<078>close<178>|<078>list<178>|<078>read filename<178>|<078>write filename<178>|<078>kill<178>}<078>\n"
 		"\n"
 		"         The {open} option will open a class, closing a previously opened\n"
 		"         class. All triggers added afterwards are assigned to this class.\n"
 		"         The {close} option will close the given class.\n"
+		"         The {list} option will show the given list of the class.\n"
 		"         The {read} option will open the class, read, and close afterwards.\n"
 		"         The {write} option will write all triggers of the given class to file.\n"
 		"         The {kill} option will delete all triggers of the given class.\n"
@@ -374,8 +376,8 @@ struct help_type help_table[] =
 		"ELSE",
 		"<178>Command<078>: #else <178>{<078>commands<178>}<078>\n"
 		"\n"
-		"         The else statement should follow an #IF or #ELSEIF statement and is only\n"
-		"         called if the proceeding #IF or #ELSEIF is false.\n"
+		"         The else statement should follow an #IF or #ELSEIF statement and is\n"
+		"         only called if the proceeding #IF or #ELSEIF is false.\n"
 		"\n"
 		"<178>Example<078>: #if {1d2 == 1} {smile};#else {grin}\n"
 	},
@@ -383,9 +385,9 @@ struct help_type help_table[] =
 		"ELSEIF",
 		"<178>Command<078>: #elseif <178>{<078>conditional<178>}<078> <178>{<078>commands<178>}<078>\n"
 		"\n"
-		"         The elseif statement should follow an #IF or #ELSEIF statement and is only\n"
-		"         called when the statement is true and the proceeding #IF and #ELSEIF statements\n"
-		"         are false.\n"
+		"         The elseif statement should follow an #IF or #ELSEIF statement and is\n"
+		"         only called when the statement is true and the proceeding #IF and\n"
+		"         #ELSEIF statements are false.\n"
 		"\n"
 		"<178>Example<078>: #if {1d3 == 1} {smirk};#elseif {1d2 == 1} {snicker}\n"
 	},
@@ -411,7 +413,7 @@ struct help_type help_table[] =
 		"         \\x7D will send the '}' character.\n"
 		"\n"
 		"         Ending a line with \\ will stop tintin from appending a line feed.\n"
-		"         To escape arguments in an alias use %%0 %%1 %%2 etc.\n"
+		"         To escape arguments in an alias or action use %%0 %%1 %%2 etc.\n"
 	},
 	{
 		"EVENT",
@@ -419,9 +421,10 @@ struct help_type help_table[] =
 		"\n"
 		"         Events allow you to create triggers for predetermined client events.\n"
 		"         Use #event without an argument to see a list of possible events with\n"
-		"         a brief description. Use #event %* to see the current list of available\n"
-		"         events you can use.\n"
+		"         a brief description. Use #event %* to see the current list of defined\n"
+		"         events.\n"
 		"\n"
+		"         CHAT MESSAGE          %0 default %1 plain\n"
 		"         DATE                  %1 month - %3 day   %4 hour : %5 minute\n"
 		"         DAY                   %3 day\n"
 		"         END OF PATH\n"
@@ -451,6 +454,7 @@ struct help_type help_table[] =
 		"         SEND OUTPUT           %0 raw text\n"
 		"         SESSION ACTIVATED     %0 name\n"
 		"         SESSION CONNECTED     %0 name %1 host %2 ip %3 port\n"
+		"         SESSION CREATED       %0 name %1 host %2 ip %3 port\n"
 		"         SESSION DEACTIVATED   %0 name\n"
 		"         SESSION DISCONNECTED  %0 name %1 host %2 ip %3 port\n"
 		"         SESSION TIMED OUT     %0 name %1 host %2 ip %3 port\n"
@@ -613,7 +617,7 @@ struct help_type help_table[] =
 		"         The highlight command is used to allow you to highlight strings of text\n"
 		"         from the mud.  Available ANSI color names are:\n"
 		"\n"
-		"         reset, light, faint, underscore, blink, reverse, dim,\n"
+		"         reset, light, dark, underscore, blink, reverse\n"
 		"\n"
 		"         black, red, green, yellow, blue, magenta, cyan, white,\n"
 		"         b black, b red, b green, b yellow, b blue, b magenta, b cyan, b white\n"
@@ -727,14 +731,18 @@ struct help_type help_table[] =
 		"         #line ignore {argument}                Argument is executed without\n"
 		"                                                any triggers being checked.\n"
 		"\n"
-		"         #line strip {argument}                 Strips the argument next\n"
-		"                                                executes it a command.\n"
+		"         #line quiet {argument}                 Argument is executed with\n"
+		"                                                suppression of system messages.\n"
+		"\n"
+		"         #line strip {argument}                 Strips the argument of color\n"
+		"                                                codes next executes it as a\n"
+		"                                                command.\n"
 		"\n"
 		"         #line substitute {options} {argument}  Substitutes the given options:\n"
 		"                                                variables, functions, colors,\n"
-		"                                                escapes, secure, eol, lnf, in\n"
-		"                                                the given argument next executes\n"
-		"                                                it as a command.\n"
+		"                                                escapes, secure, in the given\n"
+		"                                                argument next executes it as a\n"
+		"                                                command.\n"
 		"\n"
 		"         #line verbose {argument}               Argument is executed verbose.\n"
 		"\n"
@@ -747,7 +755,7 @@ struct help_type help_table[] =
 		"\n"
 		"         #list {var} {add} {item}               Add {item} to the list\n"
 		"         #list {var} {clear}                    Empty the given list\n"
-		"         #list {var} {create} {item}            Create a list using {item}\n"
+		"         #list {var} {create} {item}            Create a list using {items}\n"
 		"         #list {var} {delete} {index} {number}  Delete the item at {index},\n"
 		"                                                the {number} is optional.\n"
 		"         #list {var} {insert} {index} {string}  Insert {string} at given index\n"
@@ -791,10 +799,12 @@ struct help_type help_table[] =
 		"         or decrementing by 1 each time through.  The value of the loop counter\n"
 		"         is stored in the provided variable, which you can use in the commands.\n"
 		"\n"
-		"<178>Example<078>: #loop 1 3 loop {get all $loop.corpse}\n"
+		"<178>Example<078>: #loop 1 3 loop {get all $loop\\.corpse}\n"
 		"         This equals 'get all 1.corpse;get all 2.corpse;get all 3.corpse'.\n"
 		"\n"
-		"<178>Example<078>: #loop 3 1 cnt {drop $cnt.key}\n"
+		"         The . needs to be escaped so it's not treated as part of the variable.\n"
+		"\n"
+		"<178>Example<078>: #loop 3 1 cnt {drop $cnt\\.key}\n"
 		"         This equals 'drop 3.key;drop 2.key;drop 1.key'.\n"
 	},
 	{
@@ -840,7 +850,7 @@ struct help_type help_table[] =
 		"\n"
 		"         #map destroy: Deletes the map.\n"
 		"\n"
-		"         #map delete <direction>: Deletes the room in the given direction.\n"
+		"         #map delete <direction|vnum>: Deletes the room in the given direction.\n"
 		"\n"
 		"         #map dig <direction|vnum> [new|<vnum>]: Creates an exit in the given\n"
 		"                  direction. If no valid direction is given or no existing room\n"
@@ -864,15 +874,16 @@ struct help_type help_table[] =
 		"                  intersection is found. The route is stored in #path and can\n"
 		"                  subsequently be used with #walk\n"
 		"\n"
-		"         #map find <name> <exits> <desc> <area> <note> <terrain>\n"
+		"         #map find <name> <exits> <desc> <area> <note> <terrain> <flag>\n"
 		"                  searches for the given room name. If found the shortest path\n"
 		"                  from your current location to the destination is calculated.\n"
 		"                  The route is stored in #path and can subsequently be used with\n"
 		"                  the various #path commands. If <exits> is provided all exits\n"
-		"                  must be matched, if <roomdesc>, <roomarea> or <roomnote> is\n"
-		"                  provided these are matched as well against the room to be\n"
-		"                  found. These options are also available to the goto, and link\n"
-		"                  commands.\n"
+		"                  must be matched, if <roomdesc>, <roomarea> or <roomnote> or\n"
+		"                  <roomterrain> or <roomflag> is provided these are matched as\n"
+		"                  well against the room to be found.\n"
+		"                  These options are also available to the goto, run, delete, at\n"
+		"                  and link commands.\n"
 		"\n"
 		"         #map flag asciigraphics: Draws a smaller but more detailed map that\n"
 		"                  displays the ne se sw nw exits and room symbols.\n"
@@ -1017,7 +1028,9 @@ struct help_type help_table[] =
 		"         !               0            logical not\n"
 		"         ~               0            bitwise not\n"
 		"         *               1            integer multiply\n"
+		"         **              1            integer power\n"
 		"         /               1            integer divide\n"
+		"         //              1            integer sqrt // 2 or cbrt // 3\n"
 		"         %               1            integer modulo\n"
 		"         d               1            integer random dice roll\n"
 		"         +               2            integer addition\n"
@@ -1124,7 +1137,7 @@ struct help_type help_table[] =
 		"         direction.  The reverse direction of north is south, etc.\n"
 		"\n"
 		"         The third argument is a spatial coordinate. In general, each cardinal\n"
-		"         direction should have a unique value which is a power of two (e.g. 1, 2,\n"
+		"         direction should have a unique value which is a power of two (1, 2,\n"
 		"         4, 8, 16, 32, 64, etc). The exception is for compound directions, whose\n"
 		"         value should be the sum of the values for each component direction. For\n"
 		"         example, if the third value for 'n' is 1, and 'e' is 2, then you would\n"
@@ -1175,6 +1188,7 @@ struct help_type help_table[] =
 		"\n"
 		"       ^ force match of start of string.\n"
 		"       $ force match of end of string.\n"
+		"       \\ escape one character.\n"
 		"  %1-%99 lazy match of any text, available at &1-&99.\n"
 		"      %0 should be avoided in triggers, and if left alone &0 lists all matches.\n"
 		"     { } embed a raw regular expression, available at last &1-&99 + 1.\n"
@@ -1217,13 +1231,14 @@ struct help_type help_table[] =
 	},
 	{
 		"RUN",
-		"<178>Command<078>: #run <178>{<078>session name<178>}<078> <178>{<078>shell command<178>}<078>\n"
+		"<178>Command<078>: #run <178>{<078>name<178>}<078> <178>{<078>shell command<178>} {<078>file<178>}<078>\n"
 		"\n"
 		"         The run command works much like the system command except that it\n"
 		"         runs the command in a pseudo terminal. The run command also creates\n"
 		"         a session that treats the given shell command as a mud server. This\n"
 		"         allows you to run ssh, as well as any other shell application, with\n"
-		"         full tintin scripting capabilities\n"
+		"         full tintin scripting capabilities. If a file name is given the file\n"
+		"         is loaded prior to execution.\n"
 		"\n"
 		"<178>Example<078>: #run {somewhere} {ssh someone@somewhere.com}\n"
 		"<178>Example<078>: #run {something} {tail -f chats.log}\n"
@@ -1357,6 +1372,13 @@ struct help_type help_table[] =
 		"\n"
 		"<178>Comment<078>: You can remove split mode with the #unsplit command.\n"
 	},
+	{
+		"SSL",
+		"<178>Command<078>: #ssl <178>{<078>name<178>} {<078>host<178>} {<078>port<178>} {<078>file<178>}\n"
+		"\n"
+		"         Starts a secure socket telnet session with the given name, host, port,\n"
+		"         and optional file name.\n"
+	},
 	{
 		"STATEMENTS",
 		"         TinTin++ knows the following statements.\n"
@@ -1427,6 +1449,9 @@ struct help_type help_table[] =
 		"         and each 'case' command found will be compared to the conditional\n"
 		"         argument of the switch and executed if there is a match.\n"
 		"\n"
+		"         When comparing strings the switch and case arguments must be enclosed\n"
+		"         in quote characters.\n"
+		"\n"
 		"         If the 'default' command is found and no 'case' statement has been\n"
 		"         matched the default command's argument is executed.\n"
 		"\n"
@@ -1483,9 +1508,9 @@ struct help_type help_table[] =
 		"<178>Example<078>: #alias {target} {#var target %0}\n"
 		"         #alias {x}      {flame $target}\n"
 		"\n"
-		"         The name of a variable must exist of only letters and numbers in\n"
-		"         order to be substituted.  If you do not meet these requirements do\n"
-		"         not panic, simply encapsulate the variable in braces:\n"
+		"         The name of a variable must exist of only letters, numbers and\n"
+		"         underscores in order to be substituted.  If you do not meet these\n"
+		"         requirements do not panic, simply encapsulate the variable in braces:\n"
 		"\n"
 		"<178>Example<078>: #variable {cool website} {http://tintin.sourceforge.net}\n"
 		"         #chat I was on ${cool website} yesterday!.\n"
