@@ -140,7 +140,7 @@ void do_one_prompt(struct session *ses, char *prompt, int row)
 
 	if (len == 0)
 	{
-		sprintf(temp, "%.*s", ses->cols + 4, "\033[0m----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------");
+		sprintf(temp, "%.*s", ses->cols + 4, "\033[0m--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------");
 	}
 	else if (len <= ses->cols)
 	{
